@@ -5,7 +5,7 @@ from random import randrange
 system("")
 
 
-class BGC:
+class BGC(Enum):
     BLACK = "\x1B[40m"
     RED = "\x1B[41m"
     GREEN = "\x1B[42m"
@@ -24,7 +24,7 @@ class BGC:
     WHITE = "\x1B[107m"
 
 
-class FGC:
+class FGC(Enum):
     BLACK = "\x1B[30m"
     RED = "\x1B[31m"
     GREEN = "\x1B[32m"
@@ -43,7 +43,7 @@ class FGC:
     WHITE = "\x1B[97m"
 
 
-class ACC:
+class ACC(Enum):
     RESET = "\x1B[0m"
     RELOAD = "\x1B[!p"
     CLEARSCREEN = "\x1Bc"
@@ -60,10 +60,10 @@ class ACC:
     ALTERNATIVE_BUFF = "\x1B[?1049h"
     ORIGINAL_BUFF = "\x1B[?1049l"
 
-    def title(title):
+    def TITLE(title):
         return f"\x1B]2;{title}\x07"
 
-    def rabdomrgb(mode="Color"):
+    def RANDOMRGB(mode="Color"):
         if mode not in ["Color", "gray"]:
             mode = "Color"
         if mode == "Color":
@@ -78,88 +78,88 @@ class ACC:
             b = r
         return f"\x1B[38;2;{r};{g};{b}m"
 
-    def randomd(n):
+    def RANDOMD():
         n = randrange(0, 255)
         return f"\x1B[38;5;{n}m"
 
-    def customrgb(r, g, b):
+    def CUSTOMRGB(r, g, b):
         return f"\x1B[38;2;{r};{g};{b}m"
 
-    def customc(n):
+    def CUSTOMC(n):
         return f"\x1B[38;5;{n}m"
 
-    def bcustomrgb(r, g, b):
+    def BCUSTOMRGB(r, g, b):
         return f"\x1B[48;2;{r};{g};{b}m"
 
-    def bcustomc(n):
+    def BCUSTOMC(n):
         return f"\x1B[48;5;{n}m"
 
 
-class MCC:
-    cursor_dblink = "\x1B[?12h"
-    cursor_eblink = "\x1B[?12l"
-    cursor_hide = "\x1B[?25l"
-    cursor_show = "\x1B[?25h"
+class MCC(Enum):
+    CURSOR_DBLINK = "\x1B[?12h"
+    CURSOR_EBLINK = "\x1B[?12l"
+    CURSOR_HIDE = "\x1B[?25l"
+    CURSOR_SHOW = "\x1B[?25h"
 
-    erase_nxt_window = "\x1B[0J"
-    erase_prv_window = "\x1B[1J"
-    erase_all_window = "\x1B[2J"
-    erase_nxt_line = "\x1B[0K"
-    erase_prv_line = "\x1B[1K"
-    erase_all_line = "\x1B[2K"
-    set_tab = "\x1BH"
-    del_tab = "\x1B[0g"
-    res_tab = "\x1B[3g"
+    ERASE_NXT_WINDOW = "\x1B[0J"
+    ERASE_PRV_WINDOW = "\x1B[1J"
+    ERASE_ALL_WINDOW = "\x1B[2J"
+    ERASE_NXT_LINE = "\x1B[0K"
+    ERASE_PRV_LINE = "\x1B[1K"
+    ERASE_ALL_LINE = "\x1B[2K"
+    SET_TAB = "\x1BH"
+    DEL_TAB = "\x1B[0g"
+    RES_TAB = "\x1B[3g"
 
-    save_cursor = "\x1B[s"
-    load_cursor = "\x1B[u"
-
-    def up(count=1):
+    def UP(count=1):
         return f"\x1B[{count}A"
 
-    def down(count=1):
+    def DOWN(count=1):
         return f"\x1B[{count}B"
 
-    def right(count=1):
+    def RIGHT(count=1):
         return f"\x1B[{count}C"
 
-    def left(count=1):
+    def LEFT(count=1):
         return f"\x1B[{count}D"
 
-    def row(count=1):
+    def ROW(count=1):
         return f"\x1B[{count}G"
 
-    def cursor_position(x, y):
+    def CURSORPOSITION(x, y):
         return f"\x1B[{x};{y}H"
 
+    def SAVE_CURSOR():
+        return "\x1B[s"
 
+    def LOAD_CURSOR():
+        return "\x1B[u"
 
-
-    def scroll_down(count=1):
+    def SCROLL_DOWN(count=1):
         return f"\x1B[{count}T"
 
-    def scroll_up(count=1):
+    def SCROLL_UP(count=1):
         return f"\x1B[{count}S"
 
-    def push_right(count=1):
+    def PUSH_RIGHT(count=1):
         return f"\x1B[{count}@"
 
-    def erase_right(count=1):
+    def ERASE_RIGHT(count=1):
         return f"\x1B[{count}P"
 
-    def replace_right(count=1):
+    def REPLACE_RIGHT(count=1):
         return f"\x1B[{count}X"
 
-    def push_down(count=1):
+    def PUSH_DOWN(count=1):
         return f"\x1B[{count}L"
 
-    def erase_down(count=1):
+    def ERASE_DOWN(count=1):
         return f"\x1B{count}M"
 
-    def next_tab(count):
+    def NEXT_TAB(count):
         return f"\x1B{count}I"
 
-    def prev_tab(count):
+    def PREV_TAB(count):
         return f"\x1B{count}Z"
 
 
